#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.component.links.interfaces import IInternalLink
from pyams_content.features.header.interfaces import IHeaderTarget, IHeaderRenderer, IHeaderSettings, \
    IHeaderRendererSettings
from pyams_default_theme.features.header.interfaces import ISimpleHeaderRendererSettings
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.header.skin import BaseHeaderRenderer
from pyams_default_theme.features.header import SimpleHeaderRendererSettings
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyramid.location import lineage

from pyams_default_theme import _


SIMPLE_HEADER_RENDERER_NAME = 'PyAMS simple header'


#
# Simple header renderer
#

@adapter_config(name=SIMPLE_HEADER_RENDERER_NAME, context=(IHeaderTarget, IPyAMSLayer),
                provides=IHeaderRenderer)
@adapter_config(name=SIMPLE_HEADER_RENDERER_NAME, context=(IHeaderSettings, IPyAMSLayer),
                provides=IHeaderRenderer)
@template_config(template='templates/simple-header.pt', layer=IPyAMSLayer)
class SimpleHeaderRenderer(BaseHeaderRenderer):
    """Simple header renderer"""

    name = SIMPLE_HEADER_RENDERER_NAME
    label = _("PyAMS simple header with banner and tabs")
    weight = 1

    settings_key = 'PyAMS::simple'
    settings_interface = ISimpleHeaderRendererSettings

    def update(self):
        super(SimpleHeaderRenderer, self).update()
        self.request.annotations['REQUEST_PATH'] = list(lineage(self.request.context))

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)

    def is_active(self, link):
        if IInternalLink.providedBy(link):
            target = link.get_target()
            if target is not None:
                return target in self.request.annotations['REQUEST_PATH']
        return False


@adapter_config(context=SimpleHeaderRenderer, provides=IHeaderRendererSettings)
def simple_header_renderer_settings_factory(context):
    """Simple header renderer settings factory"""
    return SimpleHeaderRendererSettings()
